==> lambdakinesisstreams-2.34.0-sources.jar: software/amazon/awsconstructs/services/lambdakinesisstreams/LambdaToKinesisStreams.java <==
package software.amazon.awsconstructs.services.lambdakinesisstreams;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.78.1 (build 878761e)", date = "2023-03-18T14:29:46.998Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.lambdakinesisstreams.$Module.class, fqn = "@aws-solutions-constructs/aws-lambda-kinesisstreams.LambdaToKinesisStreams")
public class LambdaToKinesisStreams extends software.constructs.Construct {

    protected LambdaToKinesisStreams(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected LambdaToKinesisStreams(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public LambdaToKinesisStreams(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.lambdakinesisstreams.LambdaToKinesisStreamsProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.kinesis.Stream getKinesisStream() {
        return software.amazon.jsii.Kernel.get(this, "kinesisStream", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.kinesis.Stream.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Function getLambdaFunction() {
        return software.amazon.jsii.Kernel.get(this, "lambdaFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
    }

    public @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.cloudwatch.Alarm> getCloudwatchAlarms() {
        return java.util.Optional.ofNullable((java.util.List<software.amazon.awscdk.services.cloudwatch.Alarm>)(software.amazon.jsii.Kernel.get(this, "cloudwatchAlarms", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.Alarm.class))))).map(java.util.Collections::unmodifiableList).orElse(null);
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ec2.IVpc getVpc() {
        return software.amazon.jsii.Kernel.get(this, "vpc", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.IVpc.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.lambdakinesisstreams.LambdaToKinesisStreams}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.lambdakinesisstreams.LambdaToKinesisStreams> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.lambdakinesisstreams.LambdaToKinesisStreamsProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.lambdakinesisstreams.LambdaToKinesisStreamsProps.Builder();
        }

        /**
         * Whether to create recommended CloudWatch alarms for the Kinesis Stream.
         * <p>
         * Default: - Alarms are created
         * <p>
         * @return {@code this}
         * @param createCloudWatchAlarms Whether to create recommended CloudWatch alarms for the Kinesis Stream. This parameter is required.
         */
        public Builder createCloudWatchAlarms(final java.lang.Boolean createCloudWatchAlarms) {
            this.props.createCloudWatchAlarms(createCloudWatchAlarms);
            return this;
        }

        /**
         * Whether to deploy a new VPC.
         * <p>
         * Default: - false
         * <p>
         * @return {@code this}
         * @param deployVpc Whether to deploy a new VPC. This parameter is required.
         */
        public Builder deployVpc(final java.lang.Boolean deployVpc) {
            this.props.deployVpc(deployVpc);
            return this;
        }

        /**
         * Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingLambdaObj Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error. This parameter is required.
         */
        public Builder existingLambdaObj(final software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.props.existingLambdaObj(existingLambdaObj);
            return this;
        }

        /**
         * Existing instance of Kinesis Stream, providing both this and `kinesisStreamProps` will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingStreamObj Existing instance of Kinesis Stream, providing both this and `kinesisStreamProps` will cause an error. This parameter is required.
         */
        public Builder existingStreamObj(final software.amazon.awscdk.services.kinesis.Stream existingStreamObj) {
            this.props.existingStreamObj(existingStreamObj);
            return this;
        }

        /**
         * An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         * <p>
         * @return {@code this}
         * @param existingVpc An existing VPC for the construct to use (construct will NOT create a new VPC in this case). This parameter is required.
         */
        public Builder existingVpc(final software.amazon.awscdk.services.ec2.IVpc existingVpc) {
            this.props.existingVpc(existingVpc);
            return this;
        }

        /**
         * Optional user-provided props to override the default props for the Kinesis stream.
         * <p>
         * Default: - Default props are used.
         * <p>
         * @return {@code this}
         * @param kinesisStreamProps Optional user-provided props to override the default props for the Kinesis stream. This parameter is required.
         */
        public Builder kinesisStreamProps(final software.amazon.awscdk.services.kinesis.StreamProps kinesisStreamProps) {
            this.props.kinesisStreamProps(kinesisStreamProps);
            return this;
        }

        /**
         * User provided props to override the default props for the Lambda function.
         * <p>
         * Default: - Default props are used.
         * <p>
         * @return {@code this}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function. This parameter is required.
         */
        public Builder lambdaFunctionProps(final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.props.lambdaFunctionProps(lambdaFunctionProps);
            return this;
        }

        /**
         * Optional Name to override the Lambda Function default environment variable name that holds the Kinesis Data Stream name value.
         * <p>
         * Default: - KINESIS_DATASTREAM_NAME
         * <p>
         * @return {@code this}
         * @param streamEnvironmentVariableName Optional Name to override the Lambda Function default environment variable name that holds the Kinesis Data Stream name value. This parameter is required.
         */
        public Builder streamEnvironmentVariableName(final java.lang.String streamEnvironmentVariableName) {
            this.props.streamEnvironmentVariableName(streamEnvironmentVariableName);
            return this;
        }

        /**
         * Properties to override default properties if deployVpc is true.
         * <p>
         * @return {@code this}
         * @param vpcProps Properties to override default properties if deployVpc is true. This parameter is required.
         */
        public Builder vpcProps(final software.amazon.awscdk.services.ec2.VpcProps vpcProps) {
            this.props.vpcProps(vpcProps);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.lambdakinesisstreams.LambdaToKinesisStreams}.
         */
        @Override
        public software.amazon.awsconstructs.services.lambdakinesisstreams.LambdaToKinesisStreams build() {
            return new software.amazon.awsconstructs.services.lambdakinesisstreams.LambdaToKinesisStreams(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> lambdakinesisstreams-2.45.0-sources.jar: software/amazon/awsconstructs/services/lambdakinesisstreams/LambdaToKinesisStreams.java <==
package software.amazon.awsconstructs.services.lambdakinesisstreams;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.90.0 (build d6bdb4d)", date = "2023-10-14T14:17:03.921Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.lambdakinesisstreams.$Module.class, fqn = "@aws-solutions-constructs/aws-lambda-kinesisstreams.LambdaToKinesisStreams")
public class LambdaToKinesisStreams extends software.constructs.Construct {

    protected LambdaToKinesisStreams(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected LambdaToKinesisStreams(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope <ul><li>represents the scope for all the resources.</li></ul> This parameter is required.
     * @param id <ul><li>this is a a scope-unique id.</li></ul> This parameter is required.
     * @param props <ul><li>user provided props for the construct.</li></ul> This parameter is required.
     */
    public LambdaToKinesisStreams(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.lambdakinesisstreams.LambdaToKinesisStreamsProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.kinesis.Stream getKinesisStream() {
        return software.amazon.jsii.Kernel.get(this, "kinesisStream", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.kinesis.Stream.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Function getLambdaFunction() {
        return software.amazon.jsii.Kernel.get(this, "lambdaFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
    }

    public @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.cloudwatch.Alarm> getCloudwatchAlarms() {
        return java.util.Optional.ofNullable((java.util.List<software.amazon.awscdk.services.cloudwatch.Alarm>)(software.amazon.jsii.Kernel.get(this, "cloudwatchAlarms", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.Alarm.class))))).map(java.util.Collections::unmodifiableList).orElse(null);
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ec2.IVpc getVpc() {
        return software.amazon.jsii.Kernel.get(this, "vpc", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.IVpc.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.lambdakinesisstreams.LambdaToKinesisStreams}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.lambdakinesisstreams.LambdaToKinesisStreams> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope <ul><li>represents the scope for all the resources.</li></ul> This parameter is required.
         * @param id <ul><li>this is a a scope-unique id.</li></ul> This parameter is required.
         */
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.lambdakinesisstreams.LambdaToKinesisStreamsProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.lambdakinesisstreams.LambdaToKinesisStreamsProps.Builder();
        }

        /**
         * Whether to create recommended CloudWatch alarms for the Kinesis Stream.
         * <p>
         * Default: - Alarms are created
         * <p>
         * @return {@code this}
         * @param createCloudWatchAlarms Whether to create recommended CloudWatch alarms for the Kinesis Stream. This parameter is required.
         */
        public Builder createCloudWatchAlarms(final java.lang.Boolean createCloudWatchAlarms) {
            this.props.createCloudWatchAlarms(createCloudWatchAlarms);
            return this;
        }

        /**
         * Whether to deploy a new VPC.
         * <p>
         * Default: - false
         * <p>
         * @return {@code this}
         * @param deployVpc Whether to deploy a new VPC. This parameter is required.
         */
        public Builder deployVpc(final java.lang.Boolean deployVpc) {
            this.props.deployVpc(deployVpc);
            return this;
        }

        /**
         * Existing instance of Lambda Function object, providing both this and <code>lambdaFunctionProps</code> will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingLambdaObj Existing instance of Lambda Function object, providing both this and <code>lambdaFunctionProps</code> will cause an error. This parameter is required.
         */
        public Builder existingLambdaObj(final software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.props.existingLambdaObj(existingLambdaObj);
            return this;
        }

        /**
         * Existing instance of Kinesis Stream, providing both this and <code>kinesisStreamProps</code> will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingStreamObj Existing instance of Kinesis Stream, providing both this and <code>kinesisStreamProps</code> will cause an error. This parameter is required.
         */
        public Builder existingStreamObj(final software.amazon.awscdk.services.kinesis.Stream existingStreamObj) {
            this.props.existingStreamObj(existingStreamObj);
            return this;
        }

        /**
         * An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         * <p>
         * @return {@code this}
         * @param existingVpc An existing VPC for the construct to use (construct will NOT create a new VPC in this case). This parameter is required.
         */
        public Builder existingVpc(final software.amazon.awscdk.services.ec2.IVpc existingVpc) {
            this.props.existingVpc(existingVpc);
            return this;
        }

        /**
         * Optional user-provided props to override the default props for the Kinesis stream.
         * <p>
         * Default: - Default props are used.
         * <p>
         * @return {@code this}
         * @param kinesisStreamProps Optional user-provided props to override the default props for the Kinesis stream. This parameter is required.
         */
        public Builder kinesisStreamProps(final software.amazon.awscdk.services.kinesis.StreamProps kinesisStreamProps) {
            this.props.kinesisStreamProps(kinesisStreamProps);
            return this;
        }

        /**
         * User provided props to override the default props for the Lambda function.
         * <p>
         * Default: - Default props are used.
         * <p>
         * @return {@code this}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function. This parameter is required.
         */
        public Builder lambdaFunctionProps(final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.props.lambdaFunctionProps(lambdaFunctionProps);
            return this;
        }

        /**
         * Optional Name to override the Lambda Function default environment variable name that holds the Kinesis Data Stream name value.
         * <p>
         * Default: - KINESIS_DATASTREAM_NAME
         * <p>
         * @return {@code this}
         * @param streamEnvironmentVariableName Optional Name to override the Lambda Function default environment variable name that holds the Kinesis Data Stream name value. This parameter is required.
         */
        public Builder streamEnvironmentVariableName(final java.lang.String streamEnvironmentVariableName) {
            this.props.streamEnvironmentVariableName(streamEnvironmentVariableName);
            return this;
        }

        /**
         * Properties to override default properties if deployVpc is true.
         * <p>
         * @return {@code this}
         * @param vpcProps Properties to override default properties if deployVpc is true. This parameter is required.
         */
        public Builder vpcProps(final software.amazon.awscdk.services.ec2.VpcProps vpcProps) {
            this.props.vpcProps(vpcProps);
            return this;
        }

        /**
         * @return a newly built instance of {@link software.amazon.awsconstructs.services.lambdakinesisstreams.LambdaToKinesisStreams}.
         */
        @Override
        public software.amazon.awsconstructs.services.lambdakinesisstreams.LambdaToKinesisStreams build() {
            return new software.amazon.awsconstructs.services.lambdakinesisstreams.LambdaToKinesisStreams(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
